@@ -30,7 +30,7 @@ if (ul_t) aa[,2] = culf (aa [,2], lower = all)
 rm (s_sen, t_sen)
 gc ()
 
-aa = tokens(aa, removePunct = removePt)
+aa = tokenize(aa, remove_punct = removePt)
 len2 = length(aa) / 2
 
 aa4 = aa [1 : len2]
